@@ -1135,7 +1135,7 @@ void AnnotMarkup::initialize(XRef *xrefA, Dict *dict, Catalog *catalog, Object *
   obj1.free();
 
   if (dict->lookup("IRT", &obj1)->isDict()) {
-    inReplyTo = obj1.getDict();
+    inReplyTo = new Dict(obj1.getDict());
   } else {
     inReplyTo = NULL;
   }
@@ -1711,6 +1711,7 @@ AnnotWidget::AnnotWidget(XRef *xrefA, Dict *dict, Catalog *catalog, Object *obj)
     Annot(xrefA, dict, catalog, obj) {
   type = typeWidget;
   initialize(xrefA, catalog, dict);
+  widget = NULL;
 }
 
 AnnotWidget::~AnnotWidget() {
@@ -1827,6 +1828,7 @@ void AnnotWidget::layoutText(GooString *text, GooString *outBuf, int *i,
   double dx, dy, ox, oy;
   GBool unicode = text->hasUnicodeMarker();
   CharCodeToUnicode *ccToUnicode = font->getToUnicode();
+  ccToUnicode->decRefCnt();
   GBool spacePrev;              // previous character was a space
 
   // State for backtracking when more text has been processed than fits within
@@ -2968,6 +2970,7 @@ void AnnotWidget::generateFieldAppearance() {
     apObj.dictSet("N", &oaRef);
     annot->set("AP", &apObj);
     Dict* d = new Dict(annot);
+    d->decRef();
     Object dictObj;
     dictObj.initDict(d);
 
