@@ -10,11 +10,15 @@ public:
     unknown,
     Type1,
     Type1C,
+    Type1COT,
     Type3,
     TrueType,
+    TrueTypeOT,
     CIDType0,
     CIDType0C,
-    CIDTrueType
+    CIDType0COT,
+    CIDTrueType,
+    CIDTrueTypeOT
   };
     
   // Constructor.
@@ -25,6 +29,7 @@ public:
   ~FontInfo();
 
   GooString *getName()      { return name; };
+  GooString *getFile()      { return file; };
   Type       getType()      { return type; };
   GBool      getEmbedded()  { return emb; };
   GBool      getSubset()    { return subset; };
@@ -32,6 +37,7 @@ public:
 
 private:
   GooString *name;
+  GooString *file;
   Type type;
   GBool emb;
   GBool subset;
@@ -57,6 +63,10 @@ private:
   int fontsLen;
   int fontsSize;
 
+  Ref *visitedXObjects;
+  int visitedXObjectsLen;
+  int visitedXObjectsSize;
+
   void scanFonts(Dict *resDict, GooList *fontsList);
 };
 
